from dataclasses import dataclass
from typing import TypeVar, Callable

@dataclass
class KodiTime:
    hours: int
    minutes: int
    seconds: int

def seconds_to_kodi_format(seconds: int) -> KodiTime:
    """Convert seconds into hours, minutes, and seconds as Kodi wants that."""
    hours = seconds // 3600
    seconds -= hours * 3600
    minutes = seconds // 60
    seconds -= minutes * 60
    return KodiTime(
        hours=hours,
        minutes=minutes,
        seconds=seconds,
    )


T = TypeVar("T")
def find(l: list[T], pred: Callable[[T], bool]) -> T | None:
    for i in l:
        if pred(i):
            return i
    return None

def recursive_dict_merge(base: dict, update: dict) -> dict:
    unique_keys = set([*base.keys(), *update.keys()])
    out = {}
    for key in unique_keys:
        if key in base and key not in update:
            out[key] = base[key]
        elif key not in base and key in update:
            out[key] = update[key]
        else:
            if not isinstance(update[key], dict):
                out[key] = update[key]
            else:
                out[key] = recursive_dict_merge(base[key], update[key])
    return out